==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Draw/Hatch/ts/Hatch_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>Hatch</name>
    <message>
        <location filename="../Hatch.js" line="+55"/>
        <source>No boundary selected.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nenhum limite selecionado.</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Loop not closed at point %1/%2.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Contorno não fechado na ponta %1/%2.</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cada entidade de contorno deve ser uma linha, arco, círculo, elipse arco, elipse, polilinha ou spline. Encontrados:</translation>
    </message>
    <message>
        <location filename="../HatchInit.js" line="+2"/>
        <source>&amp;Hatch</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Hachura
Padrões de &amp;Hachura:</translatorcomment>
        <translation>&amp;Hachura</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw hatch or solid fill</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Desenhe hachura ou preenchimento sólido</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
&amp;Hachura
Hachura
Desenhe hachurados e preenchimentos sólidos</translatorcomment>
        <translation>Hachura</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Type</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Tipo de linha:
Tipo de linha
Tipo Ordinal</translatorcomment>
        <translation>Tipo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Desenhe hachurados e preenchimentos sólidos
Hachuras / preenchimentos sólidos</translatorcomment>
        <translation>Preenchimento sólido</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translatorcomment>--google--
Padrões de Hachura:
Padrões de Hachura</translatorcomment>
        <translation>Padrão hachura</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Prévia de impressão para %1
Prévia de Impressão
Exibe uma prévia da impressão</translatorcomment>
        <translation>Pré-visualizar</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translatorcomment>--exact match--
--file: pt.po--
Padrão
Padrões de Hachura:</translatorcomment>
        <translation>Padrão</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Entre o ângulo:
Insira o ângulo da linha de dimensão:</translatorcomment>
        <translation>Ângulo:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Ampliar
Escala da Superfície</translatorcomment>
        <translation>Escala:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Draw/Hatch/ts/Hatch_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Hatch</name>
    <message>
        <location filename="../Hatch.js" line="+56"/>
        <source>No boundary selected.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nenhum contorno selecionado</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Loop not closed at point %1/%2.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Contorno não fechado no ponto %1/%2.</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cada entidade de contorno deve ser uma linha, arco, círculo, elipse arco, elipse, polilinha ou uma spline. Encontrados:</translation>
    </message>
    <message>
        <location filename="../HatchInit.js" line="+2"/>
        <source>&amp;Hatch</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Hachura
Padrões de &amp;Hachura:</translatorcomment>
        <translation>&amp;Hachura</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw hatch or solid fill</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Desenhe hachura ou preenchimento sólido</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
&amp;Hachura
Hachura
Desenhe hachurados e preenchimentos sólidos</translatorcomment>
        <translation>Hachura</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Type</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Tipo de linha:
Tipo de linha
Tipo Ordinal</translatorcomment>
        <translation>Tipo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Desenhe hachurados e preenchimentos sólidos
Hachuras / preenchimentos sólidos</translatorcomment>
        <translation>Preenchimento Sólido</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translatorcomment>--google--
Padrões de Hachura:
Padrões de Hachura</translatorcomment>
        <translation>Textura da Hachura</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Prévia de impressão para %1
Prévia de Impressão
Exibe uma prévia da impressão</translatorcomment>
        <translation>Pré-visualize</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translatorcomment>--exact match--
--file: pt.po--
Padrão
Padrões de Hachura:</translatorcomment>
        <translation>Textura</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Entre o ângulo:
Insira o ângulo da linha de dimensão:</translatorcomment>
        <translation>Ângulo:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Ampliar
Escala da Superfície</translatorcomment>
        <translation>Escala:</translation>
    </message>
</context>
</TS>
